#!/bin/bash

export LANG=US
export LANGUAGE=US


################################################################
# Installing a version of LMDZ if not done yet
################################################################
version=20211102.trunk
lmdz_d=`pwd`/LMDZ$version
exec_d=$lmdz_d/1D/bin
if [ ! -d $lmdz_d ] ; then
   if [ ! -f install_lmdz.sh ] ; then
       wget http://www.lmd.jussieu.fr/~lmdz/pub/install_lmdz.sh
       chmod +x install_lmdz.sh
   fi
   ./install_lmdz.sh -v $version -bench 0 -SCM
fi


\rm -rf nz*
mkdir nz



################################################################
# Default values for the L$LLM.def file
################################################################
vert_sampling=strato_custom
vert_dzmin=0.017
vert_dzlow=1.
vert_z0low=8.7
vert_dzmid=2.
vert_z0mid=70.
vert_h_mid=20.
vert_dzhig=11.
vert_z0hig=75.
vert_h_hig=20.



cat <<eod>| gcm.sed
vert_sampling=strato_custom
vert_dzmin=$vert_dzmin
vert_dzlow=$vert_dzlow
vert_z0low=$vert_z0low
vert_dzmid=$vert_dzmid
vert_z0mid=$vert_z0mid
vert_h_mid=$vert_h_mid
vert_dzhig=$vert_dzhig
vert_z0hig=$vert_z0hig
vert_h_hig=$vert_h_hig
eod


################################################################
# Choice of the list of vertical grid choices to be plotted
################################################################
liste_cas="CMIP5-L39 L79 L59 CMIP3-L19 "
liste_cas="CMIP5-L39 CMIP3-L19 L79 V4L47"
liste_cas="CMIP3-L19 CMIP5-L39 L79"
liste_cas="CMIP5-L39 L79 L95 L130"
liste_cas="CMIP3-L19 CMIP5-L39 CMIP6-L79"
liste_cas="CMIP5-L39 CMIP6-L79 L95 L130"
liste_cas="CMIP6-L79 L500"
liste_cas="CMIP3-L19 CMIP5-L39 CMIP6-L79 L95 L130"
liste_cas="CMIP6-L79 L95 L130"
liste_cas="CMIP5-L39 CMIP6-L79 L95 V4L47"
liste_cas="CMIP5-L39 CMIP6-L79 L95 L119"
liste_cas="CMIP5-L39 CMIP6-L79 L95 L95B L119"
liste_cas="CMIP5-L39 CMIP6-L79 L95 L95B"
liste_cas="CMIP3-L19 CMIP5-L39 CMIP6-L79"
liste_cas="CMIP3-L19 CMIP5-L39 CMIP6-L79 L47B"
liste_cas="CMIP6-L79 L95 L95B"
liste_cas="CMIP6-L79 CMIP5-L39 L59"
liste_cas="CMIP6-L79 CMIP5-L39 CMIP3-L19"
liste_cas="L95B CMIP6-L79 CMIP5-L39 CMIP3-L19"



################################################################
# LOOP ON CASES
for cas in $liste_cas ; do
################################################################
   # par defaut :
   llm=79
   ok_strato=y
   ok_old_disvert=n
   
   if [ "$cas" = "CMIP6-L79" ] ;  then
       cp -f gcm.sed gcm.def
   
   elif [ "$cas" = "david" ] ; then
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      dsigmin=0.02
......eod
   
   elif [ $cas = "S130" ] ; then
      llm=130
      cat <<......eod>| gcm.def
      vert_sampling=sigma
......eod
   
   elif [ $cas = "L500" ] ; then
   
      llm=500
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_scale=7.
      vert_dzmin=0.004
      vert_dzlow=0.005
      vert_z0low=2
      vert_dzmid=0.008
      vert_z0mid=3.5
      vert_h_mid=0.3
      vert_dzhig=3.
      vert_z0hig=8
      vert_h_hig=1.
......eod

   elif [ $cas = "L130" ] ; then
   
      llm=130
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_scale=7.
      vert_dzmin=0.02
      vert_dzlow=0.03
      vert_z0low=3.
      vert_dzmid=2.
      vert_z0mid=6.
      vert_h_mid=1.
      vert_dzhig=8.
      vert_z0hig=15
      vert_h_hig=2.
......eod
   
   elif [ $cas = "L103" ] ; then
   
      llm=103
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_dzmin=0.004
      vert_dzlow=0.04
      vert_z0low=0.2
      vert_dzmid=0.5
      vert_z0mid=4.7
      vert_h_mid=2
      vert_dzhig=11.
      vert_z0hig=75.
      vert_h_hig=20.
......eod
   
   elif [ $cas = "L95" ] ; then
   
      llm=95
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_dzmin=0.017
      vert_dzlow=0.07
      vert_z0low=2.
      vert_dzmid=0.8
      vert_z0mid=6
      vert_h_mid=2
      vert_dzhig=11.
      vert_z0hig=75.
      vert_h_hig=20.
......eod
   
   elif [ $cas = "L95B" ] ; then
   
      llm=95
      cat <<......eod>| gcm.def
      vert_scale=7.
      vert_sampling=strato_custom
      vert_dzmin=0.017
      vert_dzlow=0.009
      vert_z0low=2.
      vert_dzmid=1.1
      vert_z0mid=6
      vert_h_mid=17
      vert_dzhig=10
      vert_z0hig=75.
      vert_h_hig=20.
......eod
   
   elif [ $cas = "L39B" ] ; then
   
      llm=39
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_dzmin=0.04
      vert_dzlow=0.28
      vert_z0low=2.
      vert_dzmid=2.
      vert_z0mid=15.
      vert_h_mid=10.
      vert_dzhig=6.
      vert_z0hig=50.
      vert_h_hig=8.
......eod
   
   elif [ $cas = "L35" ] ; then
   
      llm=35
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_dzmin=0.017
      vert_dzlow=0.33
      vert_z0low=2.
      vert_dzmid=4.
      vert_z0mid=17.
      vert_h_mid=10.
      vert_dzhig=8.
      vert_z0hig=50.
      vert_h_hig=8.
......eod
   
   elif [ $cas = "L35OLD" ] ; then
   
      llm=35
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_dzmin=0.06
      vert_dzlow=0.28
      vert_z0low=2.
      vert_dzmid=3
      vert_z0mid=17.
      vert_h_mid=10.
      vert_dzhig=6.
      vert_z0hig=50.
      vert_h_hig=8.
......eod
   
   elif [ $cas = "L23" ] ; then
   
      llm=23
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_dzmin=0.017
      vert_dzlow=1.
      vert_z0low=5.4
      vert_dzmid=2.
      vert_z0mid=10.
      vert_h_mid=4.
      vert_dzhig=4.
      vert_z0hig=25.
      vert_h_hig=10.
......eod
   
   elif [ $cas = "L59" ] ; then
   
      llm=59
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_dzmin=0.017
      vert_dzlow=1.2
      vert_z0low=8.4
      vert_dzmid=9.
      vert_z0mid=60.
      vert_h_mid=20.
      vert_dzhig=10.
      vert_z0hig=75.
      vert_h_hig=20.
......eod
   
   elif [ $cas = "L47B" ] ; then
   
      llm=47
      cat <<......eod>| gcm.def
      vert_scale=7.
      vert_sampling=strato_custom
      vert_dzmin=0.017
      vert_dzlow=0.09
      vert_z0low=1
      vert_dzmid=0.8
      vert_z0mid=6
      vert_h_mid=3.
      vert_dzhig=6
      vert_z0hig=25.
      vert_h_hig=10.
......eod
   
   elif [ $cas = "L119" ] ; then
   
      llm=119
      cat <<......eod>| gcm.def
      vert_scale=7.
      vert_sampling=strato_custom
      vert_dzmin=0.017
      vert_dzlow=0.003
      vert_z0low=2.
      vert_dzmid=0.8
      vert_z0mid=6
      vert_h_mid=17
      vert_dzhig=10
      vert_z0hig=75.
      vert_h_hig=20.
......eod
   
   elif [ $cas = "L79BAS" ] ; then
   
      llm=79
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_scale=7.
      vert_dzmin=0.017
      vert_dzlow=0.4
      vert_z0low=4.7
      vert_dzmid=3.5
      vert_z0mid=40.
      vert_h_mid=20.
      vert_dzhig=8
      vert_z0hig=75.
      vert_h_hig=20.
......eod
   
   elif [ $cas = "V4L47" ] ; then
   
      llm=47
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_scale=7.
      vert_dzmin=0.04
      vert_dzlow=0.85
      vert_z0low=5.
      vert_dzmid=5.5
      vert_z0mid=55
      vert_h_mid=39
      vert_dzhig=10
      vert_z0hig=80
      vert_h_hig=20
......eod
   
   elif [ $cas = "V4L39" ] ; then
   
      llm=39
      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      vert_scale=7.
      vert_dzmin=0.017
      vert_dzlow=1.15
      vert_z0low=10.
      vert_dzmid=3.
      vert_z0mid=20.
      vert_h_mid=10.
      vert_dzhig=8
      vert_z0hig=40
      vert_h_hig=15.
......eod
   
   elif [ $cas = "LOTT-L79" ] ; then
   
      cat <<......eod>| gcm.def
      pressure_exner = FALSE
      vert_sampling = strato_custom
      vert_scale=7.
      vert_dzmin=0.020
      vert_dzlow=0.900
      vert_z0low=7.0
      vert_dzmid=3.
      vert_z0mid=70.
      vert_h_mid=20.
      vert_dzhig=12.
      vert_z0hig=80.
      vert_h_hig=20.
......eod
   
   elif [ "$cas" = "bas" ] ; then

      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      dsigmin=0.02
      vert_dzmin=$vert_dzmin
      vert_dzlow=$vert_dzlow
      vert_z0low=$vert_z0low
      vert_dzmid=$vert_dzlow
      vert_z0mid=$vert_z0mid
      vert_h_mid=$vert_h_mid
      vert_dzhig=0.
      vert_z0hig=$vert_z0hig
      vert_h_hig=$vert_h_hig
......eod
   
   elif [ "$cas" = "moy" ] ; then

      cat <<......eod>| gcm.def
      vert_sampling=strato_custom
      dsigmin=0.02
      vert_dzmin=$vert_dzmin
      vert_dzlow=$vert_dzlow
      vert_z0low=$vert_z0low
      vert_dzmid=$vert_dzmid
      vert_z0mid=$vert_z0mid
      vert_h_mid=$vert_h_mid
      vert_dzhig=$vert_dzmid
      vert_z0hig=$vert_z0hig
      vert_h_hig=$vert_h_hig
......eod
   
   
   elif [ "$cas" = "strato2" ] ; then

      cat <<......eod>| gcm.def
      vert_sampling=strato_cor
      dsigmin=0.2
......eod
   
   elif [ "$cas" = CMIP5-L39 ] ; then
      llm=39
      cat <<......eod>| gcm.def
      vert_samplig=strato
      dsigmin=0.3
......eod
   
   elif  [ "$cas" = "CMIP3-L19" ] ; then

      llm=19
      ok_strato=n
      ok_old_disvert=n
      cat <<......eod>| gcm.def
      vert_samplig=tropo
......eod
   
   else
       coef=`grep coef$cas gcm.sed | awk -F= ' { print $2 * 1.5 } '`
       sed -e 's/coef'$cas'.*.$/coef'$cas'_sig='$coef'/' gcm.sed >| gcm.def
       echo SIMULATION CAS $cas
       diff gcm.sed gcm.def
   fi
   
   cat <<...eod>> gcm.def
   ok_strato=$ok_strato
   ok_old_disvert=$ok_old_disvert
   iflag_ener_conserv=1
   day_step=144
   iphysiq=1
...eod
   
   ###############################################################
   # Compiling if exectuatble non available
   (( lm1 = $llm - 1 ))
   echo $llm $lm1
   executable=$exec_d/lmdz1d_L$llm.e
   if [ ! -f "$executable" ] ; then
      cd $exec_d
      ./compile -L $llm
      cd -
   fi
   
   ###############################################################
   # Running ldmz1d.e
   $executable | grep 'PRESN.*.DZ' > tmp 2>&1
   echo $executable
   pwd
   awk ' { print $10 , $7 } ' tmp | head -$lm1 > nz/$cas
   zzlm1=`awk ' { print $7  } ' tmp | sed -n -e ${lm1}p`
   zzllm=`awk ' { print $7 } ' tmp | sed -n -e ${llm}p`
   echo $zzlm1 $zzllm | awk ' { print $2 - $1 , $2 } ' >>  nz/$cas
   
   
##################################################################
# End of loop on cases
done
##################################################################
   
   
cat <<eod>| panel1.param
    world -5, 0, 20, 130
    yaxis  tick major 20
    xaxis  tick major 5
    legend 0.15, 0.66
    world 0, 0, 0.1, 0.15
    yaxis  tick major 0.01
    xaxis  tick major 0.1
    legend 0.35, 0.28
eod

cat <<eod>| panel0.param
    world 0, 0, 11, 85
    yaxis  tick major 10
    xaxis  tick major 1
    legend 0.35, 0.3
eod
    #world 0, 0, 0.3, 0.35
    #world 0, 0, 0.35, 3.
cat <<eod>| panel2.param
    world 0, 0, 0.73, 3.
    yaxis  tick major 0.5
    xaxis  tick major 0.1
    legend 0.35, 0.3
eod
cat <<eod>| panel3.param
    world 0, 0, 6, 50.
    yaxis  tick major 2.
    xaxis  tick major 1.
    legend 0.35, 0.36
eod


for tr in 0 1 2 3 ; do

cat <<eod>> panel$tr.param
    xaxis  tick minor ticks 1
    yaxis  tick minor ticks 1
    xaxis label "d Z (km)"
    yaxis label "Z (km)"
    view 0.150000, 0.150000, 0.60000, 0.80000
    s0 symbol 2
    s0 symbol linewidth 2
    s1 symbol 1
    s1 symbol linewidth 2
    s2 symbol 3
    s2 symbol linewidth 2
    s3 symbol 4
    s4 symbol 5
    s5 symbol 6
    s6 symbol 7
    s7 symbol 8
    s8 symbol 9
    s9 symbol 10
    s10 symbol 11
    s11 symbol 12
eod


cd nz
xmgrace  -legend load $liste_cas $cas_strato  -param ../panel$tr.param -hardcopy -hdevice EPS -printfile tmp.eps
epstopdf tmp.eps
mv -f tmp.pdf zz$tr.pdf
cd ..
   
   
   
done

cd nz
pdfjam --nup 2x1 --frame true --landscape zz[02].pdf -o zzz.pdf
#pdfjam --nup 2x2 --frame true --landscape zz[0123].pdf -o zzz.pdf
